pub fn load_predicate_module(
predicate_table: &mut PredicateTable,
predicate_module: &PredicateModule,
)Expand description
Register all entries from a predicate module into the predicate table.
pub fn load_predicate_module(
predicate_table: &mut PredicateTable,
predicate_module: &PredicateModule,
)Register all entries from a predicate module into the predicate table.