pub struct Proof {
pub hypothesis: Hypothesis,
pub heap: QueryHeap,
/* private fields */
}Expand description
The proof search engine.
Maintains a goal stack and iteratively resolves goals against the predicate
table and the current hypothesis. Call Proof::prove repeatedly to
enumerate solutions via backtracking.
Fields
hypothesis: Hypothesisheap: QueryHeapImplementations
Sourceimpl Proof
impl Proof
pub fn new(heap: QueryHeap, goals: &[usize]) -> Self
Sourcepub fn with_hypothesis(
heap: QueryHeap,
goals: &[usize],
hypothesis: Hypothesis,
) -> Self
pub fn with_hypothesis( heap: QueryHeap, goals: &[usize], hypothesis: Hypothesis, ) -> Self
Create a new proof with an existing hypothesis (for negation-as-failure checks)
pub fn prove( &mut self, predicate_table: Arc<PredicateTable>, config: Config, ) -> bool